@@ -4,7 +4,7 @@ An atmospheric chemistry box model. Powered by MUSICA.
 This package contains modules for handling various aspects of a music box,
 including species, products, reactants, reactions, and more.
 """
-__version__ = "2.5.3"
+__version__ = "2.10.0"
 
 from .utils import convert_time, convert_pressure, convert_temperature, convert_concentration
 from .model_options import BoxModelOptions
@@ -13,3 +13,5 @@ from .conditions import Conditions
 from .evolving_conditions import EvolvingConditions
 from .music_box import MusicBox
 from .examples import Examples
+from .data_output import DataOutput
+from .plot_output import PlotOutput
